export declare class Vector {
    private _n;
    private _data;
    /**
     * Represents a Vector
     * @constructor
     * @param {number[]} data an array forming the vector. eg. [1, 2]
     */
    constructor(data: number[]);
    /**
     * @returns {number} returns the number dimensions of the vector
     */
    readonly dimension: number;
    /**
     * @returns {string} returns a string representation of the vector
     */
    toString(): string;
    /**
     * Add another vector to this one. Vectors must be the same size
     * @param {Vector} vector the vector to add to the first one
     * @returns {Vector} returns the new vector
     * @throws when the two vectors are of incompatible size
     */
    add(vector: Vector): Vector;
    /**
     * Mutiply another vector to this one. Vectors must be the same size
     * @param {Vector} vector the vector to multiply to the first one
     * @returns {number} returns the product of the two vectors
     * @throws when the two vectors are of incompatible size
     */
    multiply(vector: Vector): number;
    /**
     * Mutiply the vector by a scalar
     * @param {number} scalar the scalar to multiply the vector by
     * @returns {Vector} returns the new vector
     */
    multiplyByScalar(scalar: number): Vector;
    /**
     * Static alternative to toString
     * @returns {string} returns a string representation of the vector
     */
    static toString(vector: Vector): string;
    /**
     * Static alternative to add. Vectors must be the same size
     * @param {Vector} vector1 the first vector to add
     * @param {Vector} vector2 the second vector to add
     * @returns {Vector} returns the new vector
     * @throws when the two vectors are of incompatible size
     */
    static add(vector1: Vector, vector2: Vector): Vector;
    /**
     * Static alternative to multiply. Vectors must be the same size
     * @param {Vector} vector1 the first vector to multiply
     * @param {Vector} vector2 the second vector to multiply
     * @returns {number} returns the product of the two vectors
     * @throws when the two vectors are of incompatible size
     */
    static multiply(vector1: Vector, vector2: Vector): number;
    /**
     * Static alternative to multiplyByScalar
     * @param {Vector} vector the vector to multiply by the scalar
     * @param {number} scalar the scalar to multiply the vector by
     * @returns {Vector} returns the new vector
     */
    static multiplyByScalar(vector: Vector, scalar: number): Vector;
}
