export declare class Fraction {
    private numerator;
    private denominator;
    /**
     * Represents a fraction
     * @constructor
     * @param {number} numerator the numerator of the fraction
     * @param {number} denominator the denominator of the fraction
     * @throws when the numerator or the denominator is not an integer
     * @throws when the denominator is zero
     */
    constructor(numerator: number, denominator: number);
    /**
     * @returns {string} returns a string representation of the fraction
     */
    toString(): string;
    /**
     * @returns {number} returns the real value of the fraction
     */
    eval(): number;
    /**
     * Reduce the fraction. For example, 6/4 will become 3/2
     * @returns {Fraction} returns reduced fraction
     */
    reduce(): Fraction;
    /**
     * Add another fraction to this one
     * @param {Fraction} fraction the fraction to add to the first one
     * @returns {Fraction} returns the new fraction
     */
    add(fraction: Fraction): Fraction;
    /**
     * Multiply another fraction to this one
     * @param {Fraction} fraction the fraction to multiply to the first one
     * @returns {Fraction} returns the new fraction
     */
    multiply(fraction: Fraction): Fraction;
    private isInteger;
    private getGreatestCommonDivisor;
    /**
     * Static alternative to toString
     * @param {Fraction} fraction the fraction to print
     * @returns {string} returns a string representation of the fraction
     */
    static toString(fraction: Fraction): string;
    /**
     * Static alternative to eval
     * @param {Fraction} fraction the fraction to eval
     * @returns {number} returns the real value of the fraction
     */
    static eval(fraction: Fraction): number;
    /**
     * Static alternative to reduce
     * @param {Fraction} fraction the fraction to reduce
     * @returns {Fraction} returns reduced fraction
     */
    static reduce(fraction: Fraction): Fraction;
    /**
     * Static alternative to add
     * @param {Fraction} fraction1 the first fraction to add
     * @param {Fraction} fraction2 the fraction to add to the first one
     * @returns {Fraction} returns the new fraction
     */
    static add(fraction1: Fraction, fraction2: Fraction): Fraction;
    /**
     * Static alternative to multiply
     * @param {Fraction} fraction1 the first fraction to multiply
     * @param {Fraction} fraction2 the fraction to multiply to the first one
     * @returns {Fraction} returns the new fraction
     */
    static multiply(fraction1: Fraction, fraction2: Fraction): Fraction;
}
